<?php

namespace Demo\Demo\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Demo\Demo\Http\Requests\DemoUserRequest;
use Demo\Demo\Interfaces\DemoRepositoryInterface;
use Response;
use User;

class DemoUserController extends UserController
{
    /**
     * Initialize demo controller.
     *
     * @param type DemoRepositoryInterface $demo
     *
     * @return type
     */
    public function __construct(DemoRepositoryInterface $demo)
    {
        $this->model = $demo;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(DemoUserRequest $request)
    {
        $demos = $this->model->all();

        $this->theme->prependTitle(trans('demo::demo.names').' :: ');

        return $this->theme->of('demo::user.demo.index', compact('demos'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(DemoUserRequest $request, $role, $id)
    {
        $demo = $this->model->find($id);

        return $this->theme->of('demo::user.demo.show', compact('demo'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DemoUserRequest $request)
    {
        $demo = $this->model->findOrNew(0);

        Former::populate($demo);

        return $this->theme->of('demo::user.demo.create', compact('demo'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DemoUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $demo = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('demo::demo.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(DemoUserRequest $request, $role, $id)
    {
        $demo = $this->model->find($id);

        Former::populate($demo);

        return $this->theme->of('demo::user.demo.edit', compact('demo'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(DemoUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $demo = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('demo::demo.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(DemoUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('demo::demo.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
